@@ -41,4 +41,7 @@ if __name__ == '__main__':
         enable_gae=args.enable_gae,
         gpu=args.gpu)
     trainer = OnPolicyTrainer(policy, env, args, test_env=test_env)
-    trainer()
+    if args.evaluate:
+        trainer.evaluate_policy_continuously()
+    else:
+        trainer()
